@@ -1,6 +1,7 @@
 from .batch_norm import BatchNorm
 from .coupling import Coupling
 from .made import MADE
+from .one_hot import OneHot
 from .reverse import Reverse
 from .sequential import SequentialFlow
 
@@ -8,6 +9,7 @@ __all__ = (
     "BatchNorm",
     "Coupling",
     "MADE",
+    "OneHot",
     "Reverse",
     "SequentialFlow",
 )
